.. PyMacaroons documentation master file, created by
   sphinx-quickstart on Mon Sep  8 21:08:32 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. comment: split here

PyMacaroons
========

PyMacaroons is a Python implementation of Macaroons. *They're better than cookies!*

Installation
------------

Install PyMacaroons by running:

    pip install pymacaroons

Contribute
----------

- Issue Tracker: github.com/ecordell/pymacaroons/issues
- Source Code: github.com/ecordell/pymacaroons

License
-------

The project is licensed under the MIT license.


.. comment: split here

Contents:

.. toctree::
   :maxdepth: 2


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`




